@@ -15,6 +15,9 @@ from SimpleXMLRPCServer import SimpleXMLRPCDispatcher
 from jsonrpcdispatcher import JSONRPCDispatcher
 from xmlrpclib import Fault
 
+# this error code is taken from xmlrpc-epi
+# http://xmlrpc-epi.sourceforge.net/specs/rfc.fault_codes.php
+APPLICATION_ERROR = -32500
 
 def rpcmethod(**kwargs):
     '''
@@ -81,6 +84,26 @@ class RPCMethod:
             # use the passed signature if it has the correct number
             # of arguments
             self.signature = signature
+           
+    def get_stub(self):
+        '''
+        Returns a stub json for an jsonrpc request for this method
+        '''
+        
+        params = self.get_params()
+        plist = ['"' + param['name'] + '"' for param in params]
+            
+        jsonlist = [
+                   '{',
+                   '"id": "djangorpc",',
+                   '"method": "' + self.name + '",',
+                   '"params": [',
+                   '   ' + ','.join(plist),
+                   ']',
+                   '}',
+        ]
+        
+        return '\n'.join(jsonlist)
                 
     def get_returnvalue(self):
         '''
@@ -94,7 +117,8 @@ class RPCMethod:
         '''
         Returns a list of dictionaries containing name and type of the params
         
-        eg. [{'name': 'arg1', 'type': 'int'}, {'name': 'arg2', 'type': 'int'}]
+        eg. [{'name': 'arg1', 'rpctype': 'int'}, 
+             {'name': 'arg2', 'rpctype': 'int'}]
         '''
         if len(self.signature) > 0:
             arglist = []
@@ -117,8 +141,9 @@ class RPCDispatcher:
     Dispatches method calls to either the xmlrpc or jsonrpc dispatcher
     '''
     
-    def __init__(self, apps=[], restrict_introspection=False):
+    def __init__(self, url='', apps=[], restrict_introspection=False):
         version = platform.python_version_tuple()
+        self.url = url
         self.rpcmethods = []
         self.jsonrpcdispatcher = JSONRPCDispatcher()
         
@@ -145,8 +170,8 @@ class RPCDispatcher:
         '''
         
         description = {}
-        description['serviceType'] = 'RPC4Django'
-        description['serviceURL'] = '/RPC2'         # TODO: Change this!
+        description['serviceType'] = 'RPC4Django JSONRPC+XMLRPC'
+        description['serviceURL'] = self.url,
         description['methods'] = [{'name': method.name, 
                                    'summary': method.help, 
                                    'params': method.get_params(),
@@ -178,7 +203,8 @@ class RPCDispatcher:
         # this differs from what implementation in SimpleXMLRPCServer does
         # this will report via a fault or error while SimpleXMLRPCServer
         # just returns an empty string
-        raise Fault('No method found with name: '+str(method_name))
+        raise Fault(APPLICATION_ERROR, 'No method found with name: ' + \
+                    str(method_name))
           
     @rpcmethod(name='system.methodSignature', signature=['array', 'string'])
     def system_methodsignature(self, method_name):
@@ -189,7 +215,8 @@ class RPCDispatcher:
         for method in self.rpcmethods:
             if method.name == method_name:
                 return method.signature
-        raise Fault('No method found with name: '+str(method_name))
+        raise Fault(APPLICATION_ERROR, 'No method found with name: ' + \
+                    str(method_name))
                
     def register_rpcmethods(self, apps):
         '''
