@@ -19,23 +19,24 @@ from django.shortcuts import render_to_response
 from django.conf import settings
 from django.core.urlresolvers import reverse, NoReverseMatch
 from rpcdispatcher import RPCDispatcher
+from __init__ import version
 
 # these restrictions can change the functionality of rpc4django
 # but they are completely optional
 # see the rpc4django documentation for more details
-log_requests_responses = getattr(settings,
+LOG_REQUESTS_RESPONSES = getattr(settings,
                                  'RPC4DJANGO_LOG_REQUESTS_RESPONSES', True)
-restrict_introspection = getattr(settings,
+RESTRICT_INTROSPECTION = getattr(settings,
                                  'RPC4DJANGO_RESTRICT_INTROSPECTION', False)
-restrict_json = getattr(settings, 'RPC4DJANGO_RESTRICT_JSONRPC', False)
-restrict_xml = getattr(settings, 'RPC4DJANGO_RESTRICT_XMLRPC', False)
-restrict_documentation = getattr(settings,
-                                 'RPC4DJANGO_RESTRICT_DOCUMENTATION', False)
-restrict_rpctest = getattr(settings, 'RPC4DJANGO_RESTRICT_RPCTEST', False)
+RESTRICT_JSON = getattr(settings, 'RPC4DJANGO_RESTRICT_JSONRPC', False)
+RESTRICT_XML = getattr(settings, 'RPC4DJANGO_RESTRICT_XMLRPC', False)
+RESTRICT_METHOD_SUMMARY = getattr(settings, 
+                                  'RPC4DJANGO_RESTRICT_METHOD_SUMMARY', False)
+RESTRICT_RPCTEST = getattr(settings, 'RPC4DJANGO_RESTRICT_RPCTEST', False)
 
 # get a list of the installed django applications
 # these will be scanned for @rpcmethod decorators
-apps = getattr(settings, 'INSTALLED_APPS', [])
+APPS = getattr(settings, 'INSTALLED_APPS', [])
     
 
 def serve_rpc_request(request):
@@ -50,27 +51,32 @@ def serve_rpc_request(request):
     4. Try to parse as xml. Successful parse => XMLRPC
     5. JSONRPC
     '''
-    content_type = request.META['CONTENT_TYPE']
+    
 
     if request.method == "POST" and len(request.POST) > 0:
-        if log_requests_responses:
-            logging.debug('Incoming request: %s' %str(request.raw_post_data))
+        # Handle POST request with RPC payload
+        
+        content_type = request.META.get('CONTENT_TYPE', 'unknown type')
+        
+        if LOG_REQUESTS_RESPONSES:
+            logging.debug('Incoming "%s" request: %s' \
+                          %(content_type, str(request.raw_post_data)))
             
         if content_type == 'text/xml' or content_type == 'application/xml':
-            if restrict_xml:
+            if RESTRICT_XML:
                 raise Http404
             
             resp = dispatcher.xmldispatch(request.raw_post_data)
             response_type = 'text/xml'
         elif content_type.find('json') >= 0 or \
              content_type.find('javascript') >= 0:
-            if restrict_json:
+            if RESTRICT_JSON:
                 raise Http404
             
             resp = dispatcher.jsondispatch(request.raw_post_data)
             response_type = 'application/json'
         else:
-            if log_requests_responses:
+            if LOG_REQUESTS_RESPONSES:
                 logging.info('Unrecognized content-type "%s"' %content_type)
                 logging.info('Analyzing rpc request data to get content type')
                 
@@ -83,9 +89,9 @@ def serve_rpc_request(request):
                 is_xml = False
 
             # deal with the data based on what it is
-            if is_xml and restrict_xml:
+            if is_xml and RESTRICT_XML:
                 raise Http404
-            elif not is_xml and restrict_json:
+            elif not is_xml and RESTRICT_JSON:
                 raise Http404
             elif is_xml:
                 resp = dispatcher.xmldispatch(request.raw_post_data)
@@ -94,25 +100,31 @@ def serve_rpc_request(request):
                 resp = dispatcher.jsondispatch(request.raw_post_data)
                 response_type = 'application/json'
             
-        if log_requests_responses:
+        if LOG_REQUESTS_RESPONSES:
             logging.debug('Outgoing %s response: %s' %(response_type, resp))
         
         return HttpResponse(resp, response_type)
     else:
-        if restrict_documentation:
+        # Handle GET request
+        
+        if RESTRICT_METHOD_SUMMARY:
             # hide the documentation by raising 404
             raise Http404
         
         # show documentation
         methods = dispatcher.list_methods()
-        c = {
+        template_data = {
             'methods': methods,
             'url': URL,
             
+            # rpc4django version
+            'version': version(),
+            
             # restricts the ability to test the rpc server from the docs
-            'restrict_rpctest': restrict_rpctest,
+            'restrict_rpctest': RESTRICT_RPCTEST,
         }
-        return render_to_response('rpc4django/rpcmethod_summary.html', c)
+        return render_to_response('rpc4django/rpcmethod_summary.html', \
+                                  template_data)
 
 # reverse the method for use with system.describe and ajax
 try:
@@ -122,4 +134,4 @@ except NoReverseMatch:
     
 # instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
 # for any @rpcmethod decorators and adds them to the callable methods
-dispatcher = RPCDispatcher(URL, apps, restrict_introspection) 
+dispatcher = RPCDispatcher(URL, APPS, RESTRICT_INTROSPECTION) 
